"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _utils = require("../utils");

var _os = _interopRequireDefault(require("os"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let isWindows = _os.default.platform().toLowerCase() === 'win32';
let ps = _path.default.sep;
let options = (0, _utils.getOptions)();
let {
  app: {
    vendorExclude,
    customChunks
  }
} = options;

let isVendor = function isVendor(module) {
  let {
    userRequest
  } = module;
  let excludeList = ['script-loader', 'raw-loader', 'react', 'react-dom'];
  excludeList = [...excludeList, ...vendorExclude];
  return userRequest && userRequest.indexOf('node_modules') >= 0 && userRequest.endsWith('.css') === false && userRequest.endsWith('publicPathConfig.js') === false && excludeList.every(item => userRequest.indexOf(`node_modules${ps}${item}${ps}`) === -1);
};

let isReact = module => {
  let {
    userRequest
  } = module;
  let reactBundle = ['react', 'react-dom'];
  return userRequest && reactBundle.some(pkg => userRequest.indexOf(`node_modules${ps}${pkg}${ps}`) >= 0);
};

let defaultChunks = {
  'react.vendor': {
    name: 'react.vendor',
    chunks: 'all',
    minChunks: 1,
    test: isReact,
    priority: -10
  },
  vendor: {
    name: 'vendor',
    chunks: 'all',
    minChunks: 1,
    test: isVendor,
    priority: -10
  }
};
let customChunksConfig = {};
customChunks.map(({
  name,
  pattern,
  size = 2
}, index) => customChunksConfig[name] = {
  name,
  test: new RegExp(isWindows ? pattern.replace(/\//g, '\\') : pattern),
  chunks: 'all',
  enforce: true,
  minChunks: size,
  priority: -10 * (index + 2)
});
var _default = {
  cacheGroups: Object.assign({
    default: false,
    vendors: false
  }, defaultChunks, customChunksConfig)
};
exports.default = _default;