"use strict";

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let appPath = process.cwd();
let commonConfig = {
  coverageReporters: ['json', 'html', 'json-summary', 'text'],
  collectCoverage: true,
  moduleDirectories: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules'],
  transform: {
    '^.+\\.(js|jsx)$': _path.default.resolve(__dirname, '..', 'jest', 'preProcessors', 'jsPreprocessor.js'),
    '^.+\\.css$': _path.default.resolve(__dirname, '..', 'jest', 'preProcessors', 'cssPreprocessor.js'),
    '^(?!.*\\.(js|jsx|css|json)$)': _path.default.resolve(__dirname, '..', 'jest', 'preProcessors', 'otherFilesPreprocessor.js')
  },
  moduleNameMapper: {
    '\\.(css|less)$': 'identity-obj-proxy'
  },
  transformIgnorePatterns: ['/node_modules.*?.js$'],
  moduleFileExtensions: ['js'],
  setupFiles: [_path.default.resolve(appPath, '__testUtils__', 'globals.js'), _path.default.resolve(__dirname, '..', 'jest', 'setup.js')],
  globals: {
    __DEVELOPMENT__: true,
    __DOCS__: false,
    __TEST__: true
  }
};

module.exports = (...args) => {
  let [appFolder, forCommittedFiles = false] = args;

  if (forCommittedFiles) {
    return Object.assign({}, commonConfig, {
      coverageDirectory: _path.default.resolve(appPath, 'commitCoverage'),
      testResultsProcessor: _path.default.resolve(__dirname, '..', 'jest', 'commitedFilesResult.js')
    });
  }

  return Object.assign({}, commonConfig, {
    rootDir: appPath,
    testPathIgnorePatterns: ['/node_modules/', 'docs'],
    unmockedModulePathPatterns: ['__tests__', 'node_modules', '.*'],
    roots: [`<rootDir>/${appFolder}/`],
    testRegex: '(/__tests__/.*|\\.(test|spec))\\.(jsx|js|json|node)$',
    testResultsProcessor: _path.default.resolve(__dirname, '..', 'jest', 'result.js')
  });
};