"use strict";

var _path = _interopRequireDefault(require("path"));

var _utils = require("../utils");

var _common = require("../common");

var _pluginUtils = require("../pluginUtils");

var _loaderUtils = require("../loaderUtils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let options = (0, _utils.getOptions)();
let {
  app: {
    folder,
    context,
    server,
    outputFolder,
    rtlExclude,
    hasRTL,
    cssUniqueness,
    seperateCssModules,
    changeRuntimeChunkChar,
    cssHashSelectors,
    classNamePrefix,
    selectorReplace,
    disableES5Transpile
  }
} = options;
let {
  disableContextURL
} = server;
let appPath = process.cwd();
let contextURL = disableContextURL ? '' : context;
let serverUrl = (0, _utils.getServerURL)(server, 'https');
let output = {
  path: _path.default.join(appPath, outputFolder),
  filename: 'js/[name].js',
  chunkFilename: 'js/[name].js',
  publicPath: `${[serverUrl, contextURL].filter(a => a).join('/')}/`,
  jsonpFunction: `${context}Jsonp`
};
module.exports = {
  entry: (0, _common.getEntries)(options, 'dev'),
  devtool: 'cheap-eval-source-map',
  mode: 'development',
  output,
  stats: {
    children: false
  },
  optimization: {
    splitChunks: _common.splitChunks,
    moduleIds: 'named',
    runtimeChunk: {
      name: entrypoint => changeRuntimeChunkChar ? `./runtime-${entrypoint.name}` : `./runtime~${entrypoint.name}`
    }
  },
  plugins: (0, _pluginUtils.getDevPlugins)(options, output.publicPath),
  module: {
    /* strictExportPresence for break the build when imported module not present in respective file */
    strictExportPresence: true,
    rules: [{
      test: /\.js$/,
      use: (0, _loaderUtils.getDevJsLoaders)(options),
      include: _path.default.join(appPath, folder)
    }, seperateCssModules ? {
      test: /\.css$/,
      exclude: /\.module\.css$/,
      use: (0, _loaderUtils.getCSSLoaders)(hasRTL, rtlExclude, '[local]', false, null)
    } : null, {
      test: seperateCssModules ? /\.module\.css$/ : /(\.module)?\.css$/,
      use: (0, _loaderUtils.getCSSLoaders)(hasRTL, rtlExclude, null, cssUniqueness, selectorReplace, cssHashSelectors, classNamePrefix)
    }, {
      test: /\.jpe?g$|\.gif$|\.png$/,
      use: ['url-loader?limit=1000&name=./images/[name].[ext]']
    }, {
      test: /\.woff2|\.woff$|\.ttf$|\.eot$/,
      use: ['url-loader?limit=1000&name=./fonts/[name].[ext]']
    }, {
      test: /\.svg$/,
      use: ['url-loader?limit=1&name=./fonts/[name].[ext]']
    }, {
      test: /\.ogg$/,
      use: ['file-loader?name=./fonts/[name].[ext]']
    }, {
      test: /\.tmpl$/,
      use: [{
        loader: 'html-loader',
        options: {
          minimize: true
        }
      }]
    }, {
      test: /\.worker.js$/,
      use: {
        loader: require.resolve('../loaders/workerLoader.js'),
        options: {
          esModule: true,
          filename: 'js/[name].js'
        }
      }
    }].filter(Boolean)
  },
  externals: {
    ZC: '$ZC'
  },
  resolve: {
    modules: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules'],
    alias: disableES5Transpile ? {
      '@zohodesk/components/lib': '@zohodesk/components/es',
      '@zohodesk/dot/lib': '@zohodesk/dot/es',
      '@zohodesk/i18n/lib': '@zohodesk/i18n/es',
      '@zohodesk/icons/lib': '@zohodesk/icons/es',
      '@zohodesk/normalizer/lib': '@zohodesk/normalizer/es',
      '@zohodesk/perf-components/lib': '@zohodesk/perf-components/es',
      '@zohodesk/perf-middleware/lib': '@zohodesk/perf-middleware/es',
      '@zohodesk/permissions/lib': '@zohodesk/permissions/es',
      '@zohodesk/platform-middleware/lib': '@zohodesk/platform-middleware/es',
      '@zohodesk/react-dnd/lib': '@zohodesk/react-dnd/es',
      '@zohodesk/router-middleware/lib': '@zohodesk/router-middleware/es',
      '@zohodesk/storage/lib': '@zohodesk/storage/es',
      '@zohodesk/svg/lib': '@zohodesk/svg/es',
      '@zohodesk/timetracker/lib': '@zohodesk/timetracker/es',
      '@zohodesk/variables/lib': '@zohodesk/variables/es',
      '@zohodesk/virtualizer/lib': '@zohodesk/virtualizer/es'
    } : {}
  },
  resolveLoader: {
    modules: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules']
  }
};