"use strict";

var _path = _interopRequireDefault(require("path"));

var _utils = require("../utils");

var _pluginUtils = require("../pluginUtils");

var _loaderUtils = require("../loaderUtils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let options = (0, _utils.getOptions)();
let {
  docs: {
    componentFolder,
    cssUniqueness,
    hasRTL,
    rtlExclude,
    cssHashSelectors,
    classNamePrefix
  },
  app: {
    folder
  }
} = options;
let appPath = process.cwd();

module.exports = isSSTest => ({
  entry: {
    main: [_path.default.resolve(__dirname, '..', 'hooks', 'docsProptypeHook.js'), _path.default.join(appPath, componentFolder, 'index.js')],
    vendor: ['react', 'react-dom', 'redux', 'react-redux']
  },
  devtool: 'none',
  mode: 'development',
  output: {
    path: _path.default.join(appPath, 'build'),
    filename: 'js/[name].js',
    publicPath: '/docs/',
    library: 'Component',
    libraryTarget: 'umd'
  },
  plugins: (0, _pluginUtils.getDocsPlugins)(isSSTest, options),
  module: {
    rules: [{
      test: /\.js$/,
      use: [{
        loader: 'babel-loader',
        options: {
          presets: [[require.resolve('@babel/preset-env'), {
            modules: false
          }], require.resolve('@babel/preset-react')],
          plugins: [[require.resolve('@babel/plugin-transform-runtime'), {
            helpers: true,
            regenerator: false
          }], require.resolve('babel-plugin-syntax-dynamic-import'), require.resolve('babel-plugin-syntax-object-rest-spread')],
          cacheDirectory: true
        }
      }],
      include: _path.default.join(appPath, folder)
    }, {
      test: /\.docs\.js$/,
      use: require.resolve('../loaders/docsLoader.js'),
      include: _path.default.join(appPath, folder),
      exclude: /node_modules/
    }, {
      test: /(\.module)?\.css$/,
      use: (0, _loaderUtils.getCSSLoaders)(hasRTL, rtlExclude, false, cssUniqueness, null, cssHashSelectors, classNamePrefix)
    }, {
      test: /\.jpe?g$|\.gif$|\.png$/,
      use: ['url-loader?limit=1000&name=./images/[name].[ext]']
    }, {
      test: /\.woff2|\.woff$|\.ttf$|\.eot$/,
      use: ['url-loader?limit=1000&name=./fonts/[name].[ext]']
    }, {
      test: /\.svg$/,
      use: ['url-loader?limit=1&name=./fonts/[name].[ext]']
    }, {
      test: /\.html$/,
      use: {
        loader: 'html-loader',
        options: {
          attrs: [':data-src'],
          interpolate: 'require'
        }
      }
    }, {
      test: /\.ogg$/,
      use: ['file-loader?name=./fonts/[name].[ext]']
    }, {
      test: /\.tmpl$/,
      use: [{
        loader: 'html-loader',
        options: {
          interpolate: 'require',
          ignoreCustomFragments: [/\{\{.*?}}/, /\$\{.*?}/],
          minimize: true,
          removeComments: true,
          collapseWhitespace: false,
          removeAttributeQuotes: false,
          minifyCSS: false,
          minifyJS: false
        }
      }]
    }]
  },
  externals: {
    ZC: '$ZC'
  },
  resolve: {
    modules: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules']
  },
  resolveLoader: {
    modules: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules']
  }
});