"use strict";

var _path = _interopRequireDefault(require("path"));

var _utils = require("../utils");

var _common = require("../common");

var _pluginUtils = require("../pluginUtils");

var _loaderUtils = require("../loaderUtils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let options = (0, _utils.getOptions)();
let {
  app: {
    folder,
    context,
    enableChunkHash,
    outputFolder,
    disableES5Transpile,
    removeAttribute,
    enableSMap,
    server,
    hasRTL,
    rtlExclude,
    cssUniqueness,
    server: {
      mode
    },
    seperateCssModules,
    changeRuntimeChunkChar,
    cssHashSelectors,
    classNamePrefix,
    selectorReplace,
    removePropTypes
  }
} = options;
let appPath = process.cwd();
let isDevelopment = mode === 'prod' || mode === 'dev' || mode === 'dev-no-warn';
enableChunkHash = !isDevelopment && enableChunkHash;
let output = {
  path: _path.default.resolve(appPath, outputFolder),
  filename: enableChunkHash ? './js/[name].[chunkhash:20]_.js' : './js/[name]_.js',
  chunkFilename: enableChunkHash ? './js/[name].[chunkhash:20]_.js' : './js/[name]_.js',
  jsonpFunction: `${context}Jsonp`,
  sourceMapFilename: enableChunkHash ? 'smap/[name].[chunkhash:20]_.map' : 'smap/[name]_.map'
};

if (isDevelopment) {
  let {
    disableContextURL
  } = server;
  let contextURL = disableContextURL ? '' : context;
  let serverUrl = (0, _utils.getServerURL)(server, 'https');
  output.publicPath = `${[serverUrl, contextURL].filter(a => a).join('/')}/`;
}

let shouldRemovePropTypes = !isDevelopment && removePropTypes;
module.exports = {
  entry: (0, _common.getEntries)(options, 'production'),
  devtool: isDevelopment ? 'cheap-module-source-map' : enableSMap ? 'hidden-source-map' : 'none',
  mode: 'production',
  output,
  optimization: {
    splitChunks: _common.splitChunks,
    runtimeChunk: {
      name: entrypoint => changeRuntimeChunkChar ? `./runtime-${entrypoint.name}` : `./runtime~${entrypoint.name}`
    },
    concatenateModules: true,
    minimize: true,
    moduleIds: 'named'
  },
  stats: {
    children: false,
    colors: true,
    // excludeAssets: /i18n/,
    warningsFilter: /\[mini-css-extract-plugin\]/
  },
  plugins: (0, _pluginUtils.getProdPlugins)(options, output.publicPath),
  module: {
    /* strictExportPresence for break the build when imported module not present in respective file */
    strictExportPresence: true,
    rules: [{
      test: /\.js$/,
      use: [{
        loader: 'babel-loader',
        options: {
          presets: [[require.resolve('@babel/preset-env'), disableES5Transpile ? {
            modules: false,
            useBuiltIns: 'usage',
            corejs: 3,
            targets: {
              browsers: ['last 3 Chrome versions', 'last 3 Firefox versions', 'last 3 Edge versions', 'last 3 Safari versions']
            }
          } : {
            modules: false
          }], require.resolve('@babel/preset-react')],
          plugins: disableES5Transpile ? [removeAttribute ? require.resolve('../utils/removeAttributes') : false, require.resolve('@babel/plugin-syntax-dynamic-import'), require.resolve('babel-plugin-lodash'), require.resolve('@babel/plugin-proposal-object-rest-spread')].filter(Boolean) : [removeAttribute ? require.resolve('../utils/removeAttributes') : false, shouldRemovePropTypes ? [require.resolve('babel-plugin-transform-react-remove-prop-types'), removePropTypes] : false[(require.resolve('@babel/plugin-transform-runtime'), {
            helpers: true,
            regenerator: false
          }, require.resolve('@babel/plugin-proposal-object-rest-spread'))], require.resolve('@babel/plugin-syntax-dynamic-import'), require.resolve('babel-plugin-lodash')].filter(Boolean),
          cacheDirectory: true
        }
      }],
      include: _path.default.join(appPath, folder)
    }, seperateCssModules ? {
      test: /\.css$/,
      exclude: /\.module\.css$/,
      use: (0, _loaderUtils.getCSSLoaders)(hasRTL, rtlExclude, '[local]', false, null)
    } : null, {
      test: seperateCssModules ? /\.module\.css$/ : /(\.module)?\.css$/,
      use: (0, _loaderUtils.getCSSLoaders)(hasRTL, rtlExclude, false, cssUniqueness, selectorReplace, cssHashSelectors, classNamePrefix)
    }, {
      test: /\.jpe?g$|\.gif$|\.png$/,
      use: [{
        loader: 'url-loader',
        options: {
          limit: 1000,
          name: enableChunkHash ? './images/[name].[hash:20].[ext]' : './images/[name].[ext]',
          fallback: _path.default.join(__dirname, '..', 'loaders', 'fileLoader.js')
        }
      }]
    }, {
      test: /\.woff2|\.woff$|\.ttf$|\.eot$/,
      use: [{
        loader: 'url-loader',
        options: {
          limit: 1000,
          name: enableChunkHash ? './fonts/[name].[hash:20].[ext]' : './fonts/[name].[ext]',
          fallback: _path.default.join(__dirname, '..', 'loaders', 'fileLoader.js')
        }
      }]
    }, {
      test: /\.svg$/,
      use: [{
        loader: 'url-loader',
        options: {
          limit: 1,
          name: enableChunkHash ? './fonts/[name].[hash:20].[ext]' : './fonts/[name].[ext]',
          fallback: _path.default.join(__dirname, '..', 'loaders', 'fileLoader.js')
        }
      }]
    }, {
      test: /\.ogg$/,
      use: [{
        loader: 'file-loader',
        options: {
          name: enableChunkHash ? './fonts/[name].[hash:20].[ext]' : './fonts/[name].[ext]'
        }
      }]
    }, {
      test: /\.tmpl$/,
      use: [{
        loader: 'html-loader',
        options: {
          minimize: false
        }
      }]
    }, {
      test: /\.worker.js$/,
      use: {
        loader: require.resolve('../loaders/workerLoader.js'),
        options: {
          esModule: true,
          filename: 'js/[name].[chunkhash:20].js'
        }
      }
    }].filter(Boolean)
  },
  externals: {
    ZC: '$ZC'
  },
  resolve: {
    modules: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules'],
    alias: disableES5Transpile ? {
      '@zohodesk/components/lib': '@zohodesk/components/es',
      '@zohodesk/dot/lib': '@zohodesk/dot/es',
      '@zohodesk/i18n/lib': '@zohodesk/i18n/es',
      '@zohodesk/icons/lib': '@zohodesk/icons/es',
      '@zohodesk/normalizer/lib': '@zohodesk/normalizer/es',
      '@zohodesk/perf-components/lib': '@zohodesk/perf-components/es',
      '@zohodesk/perf-middleware/lib': '@zohodesk/perf-middleware/es',
      '@zohodesk/permissions/lib': '@zohodesk/permissions/es',
      '@zohodesk/platform-middleware/lib': '@zohodesk/platform-middleware/es',
      '@zohodesk/react-dnd/lib': '@zohodesk/react-dnd/es',
      '@zohodesk/router-middleware/lib': '@zohodesk/router-middleware/es',
      '@zohodesk/storage/lib': '@zohodesk/storage/es',
      '@zohodesk/svg/lib': '@zohodesk/svg/es',
      '@zohodesk/timetracker/lib': '@zohodesk/timetracker/es',
      '@zohodesk/variables/lib': '@zohodesk/variables/es',
      '@zohodesk/virtualizer/lib': '@zohodesk/virtualizer/es'
    } : {}
  },
  resolveLoader: {
    modules: [_path.default.resolve(__dirname, '..', '..', 'node_modules'), 'node_modules']
  }
};