"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _caseSensitivePathsWebpackPlugin = _interopRequireDefault(require("case-sensitive-paths-webpack-plugin"));

var _lodashWebpackPlugin = _interopRequireDefault(require("lodash-webpack-plugin"));

var _miniCssExtractPlugin = _interopRequireDefault(require("mini-css-extract-plugin"));

var _htmlWebpackPlugin = _interopRequireDefault(require("html-webpack-plugin"));

var _I18nSplitPlugin = _interopRequireDefault(require("../plugins/I18nSplitPlugin"));

var _copyWebpackPlugin = _interopRequireDefault(require("copy-webpack-plugin"));

var _webpack = _interopRequireDefault(require("webpack"));

var _plugins = require("../plugins");

var _common = require("../common");

var _CustomAttributePlugin = require("../plugins/CustomAttributePlugin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let getDevPlugins = (options, publicPath) => {
  let {
    app: {
      tpFolder,
      folder,
      instrumentScript,
      customAttributes,
      context,
      hasEFC: prevOptionForEnableEFC,
      hasShadowDOM,
      server: {
        mode
      },
      htmlTemplate: {
        inject
      }
    },
    efc: {
      hasEFC: newOptionForEnableEFC,
      nameScope: efcNameSpace,
      localeAttr: efcLocaleAttr
    },
    i18n,
    unusedFiles
  } = options;
  const hasEFC = newOptionForEnableEFC || prevOptionForEnableEFC;
  let plugins = [new _plugins.CleanUpStatsPlugin(), new _caseSensitivePathsWebpackPlugin.default(), new _webpack.default.IgnorePlugin(/^\.\/domain$/, /moment$/), new _webpack.default.DefinePlugin({
    __CLIENT__: true,
    __TEST__: false,
    __SERVER__: false,
    __DEVELOPMENT__: true,
    __LOCAL_PRODUCTION__: false,
    __DEVTOOLS__: true,
    __DOCS__: false,
    'process.env': {
      NODE_ENV: JSON.stringify(mode === 'dev-no-warn' ? 'production' : 'development')
    }
  }), new _miniCssExtractPlugin.default({
    attributes: customAttributes.cssAttributes,
    filename: 'css/[name].css',
    chunkFilename: 'css/[name].css',
    ignoreOrder: true
  }), new _plugins.ResourceHintsPlugin()];

  if (unusedFiles.enable) {
    plugins.push(new _plugins.UnusedFilesFindPlugin(Object.assign(unusedFiles, {
      origin: _path.default.join(process.cwd(), folder)
    })));
  }

  const i18nManifestFileName = 'i18n-manifest.json';
  /**
   * NOTE:
   *  this file name ext .i18n.js added
   *  Because, in service worker they maintain cache as file name based
   *  So, to make differce we added .i18n.js ext.
   */

  const i18nFileNameTemplate = 'i18n-chunk/[locale]/[name].i18n.js';
  const i18nPublicPath = publicPath || '';

  if (i18n.chunkSplitEnable) {
    plugins.push(new _I18nSplitPlugin.default({
      jsResource: i18n.jsResource,
      localeVarName: i18n.localeVarName,
      jsonpFunc: i18n.jsonpFunc,
      disableDefault: i18n.disableDefault,
      publicPath: i18nPublicPath,
      i18nManifestFileName,
      // template: (object, locale) => `window.loadI18n(${JSON.stringify(object)}, ${JSON.stringify(locale)})`,
      filenameTemplate: i18nFileNameTemplate,
      propertiesFolder: i18n.propertiesFolder
    }));
  } else {
    plugins.push(new _copyWebpackPlugin.default({
      patterns: [{
        from: `${_path.default.join(process.cwd(), context, 'i18n')}/`,
        to: './i18n/[name].[ext]',
        toType: 'template'
      }]
    }));
  }

  tpFolder && plugins.push(new _copyWebpackPlugin.default({
    patterns: [{
      from: `${_path.default.join(process.cwd(), context, tpFolder)}/`,
      to: `./${tpFolder}/`,
      toType: 'dir'
    }]
  }));
  plugins.push(new _lodashWebpackPlugin.default({
    collections: true,
    shorthands: true
  }));

  if (hasEFC) {
    plugins.push(new _htmlWebpackPlugin.default({
      chunksSortMode: 'none',
      filename: 'index.html',
      template: _path.default.join(process.cwd(), folder, 'index.html'),
      excludeChunks: ['efc', 'widget'],
      templateParameters: _common.templateParameters,
      scriptLoading: 'defer',
      inject: inject
    }));
    plugins.push(new _plugins.EFCPlugin({
      isDevelopment: true,
      i18nManifestFileName,
      i18nFileNameTemplate,
      serverUrl: publicPath,
      entryPointName: 'efc',
      nameScope: efcNameSpace,
      localeAttr: efcLocaleAttr // outputFile: 'zohodesk-efc-sdk-latest.js',

    }));
  } else {
    plugins.push(new _htmlWebpackPlugin.default({
      chunksSortMode: 'none',
      filename: 'index.html',
      template: _path.default.join(process.cwd(), folder, 'index.html'),
      templateParameters: _common.templateParameters,
      scriptLoading: 'defer',
      inject: inject
    }));
  }

  plugins.push(new _plugins.I18NInjectIntoIndexPlugin({
    publicPath: i18nPublicPath,
    isDevelopment: true,
    templateLabel: i18n.templateLabel || '{{--user-locale}}',
    i18nFileNameTemplate,
    i18nManifestFileName,
    mainChunkName: 'main'
  }));
  instrumentScript && plugins.push(new _plugins.ScriptInstrumentPlugin());
  customAttributes.enable && plugins.push(new _CustomAttributePlugin.CustomAttributePlugin(customAttributes));
  hasShadowDOM && plugins.push(new _plugins.ShadowDOMSupportPlugin());
  return plugins.filter(Boolean);
};

var _default = getDevPlugins;
exports.default = _default;