"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _webpack = _interopRequireDefault(require("webpack"));

var _caseSensitivePathsWebpackPlugin = _interopRequireDefault(require("case-sensitive-paths-webpack-plugin"));

var _webpackBundleAnalyzer = require("webpack-bundle-analyzer");

var _lodashWebpackPlugin = _interopRequireDefault(require("lodash-webpack-plugin"));

var _miniCssExtractPlugin = _interopRequireDefault(require("mini-css-extract-plugin"));

var _I18nSplitPlugin = _interopRequireDefault(require("../plugins/I18nSplitPlugin"));

var _htmlWebpackPlugin = _interopRequireDefault(require("html-webpack-plugin"));

var _copyWebpackPlugin = _interopRequireDefault(require("copy-webpack-plugin"));

var _plugins = require("../plugins");

var _common = require("../common");

var _CustomAttributePlugin = require("../plugins/CustomAttributePlugin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-next-line no-unused-vars
let getProdPlugins = (options, publicPath = '') => {
  let {
    enableChunkHash,
    manifestFileName,
    bundleAnalyze,
    optimize,
    publicPaths,
    hasEFC: prevOptionForEnableEFC,
    enableSMapHook,
    tpFolder,
    folder,
    outputFolder,
    context,
    enableSMap,
    server: {
      mode
    },
    hasShadowDOM,
    resourceHints,
    serviceWorker,
    htmlTemplate: {
      inject
    },
    customAttributes,
    tpHashMapping,
    cdnMapping
  } = options.app;
  const {
    i18n
  } = options;
  const {
    hasEFC: newOptionForEnableEFC,
    nameScope: efcNameSpace,
    localeAttr: efcLocaleAttr
  } = options.efc;
  const hasEFC = newOptionForEnableEFC || prevOptionForEnableEFC;
  let isDevelopment = mode === 'prod' || mode === 'dev' || mode === 'dev-no-warn';
  enableChunkHash = !isDevelopment && enableChunkHash;
  let plugins = [new _caseSensitivePathsWebpackPlugin.default(), new _webpack.default.IgnorePlugin(/^\.\/locale$/, /moment$/), new _webpack.default.DefinePlugin({
    __TEST__: false,
    __DEVELOPMENT__: false,
    __LOCAL_PRODUCTION__: isDevelopment,
    __DOCS__: false,
    'process.env': {
      NODE_ENV: JSON.stringify('production')
    },
    __SERVER__: false
  }), new _miniCssExtractPlugin.default({
    filename: enableChunkHash ? './css/[name].[chunkhash:20]_.css' : './css/[name]_.css',
    chunkFilename: enableChunkHash ? './css/[name].[chunkhash:20]_.css' : './css/[name]_.css',
    ignoreOrder: true
  }), new _plugins.ResourceHintsPlugin(), new _plugins.UglifyCSSPlugin()];
  const i18nManifestFileName = 'i18n-manifest.json';
  /**
   * NOTE:
   *  this file name ext .i18n.js added
   *  Because, in service worker they maintain cache as file name based
   *  So, to make differce we added .i18n.js ext.
   */

  const i18nFileNameTemplate = 'i18n-chunk/[locale]/[name].[chunkhash].i18n.js';
  const i18nPublicPath = Array.isArray(publicPaths) && !cdnMapping.isCdnEnabled ? publicPaths['4'] : ''; // const  i18nFileNameTemplate = 'i18n-chunk/[locale]/[name].[contentHash]_.js';
  // const  i18nFileNameTemplate = 'i18n-chunk/[locale]/[name]_.js';

  if (i18n.chunkSplitEnable) {
    plugins.push(new _I18nSplitPlugin.default({
      jsResource: i18n.jsResource,
      localeVarName: i18n.localeVarName,
      jsonpFunc: i18n.jsonpFunc,
      disableDefault: i18n.disableDefault,
      publicPath: i18nPublicPath,
      i18nManifestFileName,
      // template: (object, locale) => `window.loadI18n(${JSON.stringify(object)}, ${JSON.stringify(locale)})`,
      filenameTemplate: i18nFileNameTemplate,
      propertiesFolder: i18n.propertiesFolder
    }));
  } else {
    plugins.push(new _copyWebpackPlugin.default({
      patterns: [{
        from: `${_path.default.join(process.cwd(), context, 'i18n')}/`,
        to: enableChunkHash ? './i18n/[name].[hash:20]_.[ext]' : './i18n/[name]_.[ext]',
        toType: 'template'
      }]
    }));
  }

  tpFolder && plugins.push(new _copyWebpackPlugin.default({
    patterns: [{
      from: `${_path.default.join(process.cwd(), context, tpFolder)}/`,
      to: `./${tpFolder}/`,
      toType: 'dir'
    }]
  }));

  if (hasEFC) {
    plugins.push(new _htmlWebpackPlugin.default({
      chunksSortMode: 'none',
      filename: enableChunkHash ? 'index.[templatehash:20].html' : 'index.html',
      template: _path.default.join(process.cwd(), folder, 'index.html'),
      excludeChunks: ['efc', 'widget'],
      minify: false,
      templateParameters: _common.templateParameters,
      scriptLoading: 'defer',
      inject: inject
    }));
    plugins.push(new _plugins.EFCPlugin({
      isDevelopment,
      serverUrl: publicPath,
      i18nFileNameTemplate,
      i18nManifestFileName,
      entryPointName: 'efc',
      // outputFile: 'zohodesk-efc-sdk-latest.js',
      nameScope: efcNameSpace,
      localeAttr: efcLocaleAttr,
      cdnVariableName: cdnMapping.isCdnEnabled ? cdnMapping.variableName : null
    }));
  } else {
    plugins.push(new _htmlWebpackPlugin.default({
      chunksSortMode: 'none',
      filename: enableChunkHash ? 'index.[templatehash:20].html' : 'index.html',
      template: _path.default.join(process.cwd(), folder, 'index.html'),
      minify: false,
      templateParameters: _common.templateParameters,
      scriptLoading: 'defer',
      inject: inject
    }));
  }

  plugins.push(new _plugins.I18NInjectIntoIndexPlugin({
    // Because we  will handle cdn url in CdnChangePlugin
    publicPath: cdnMapping.isCdnEnabled ? '' : i18nPublicPath,
    isDevelopment,
    templateLabel: i18n.templateLabel || '{{--user-locale}}',
    i18nFileNameTemplate,
    i18nManifestFileName,
    mainChunkName: 'main'
  }));

  if (publicPaths && !isDevelopment && !cdnMapping.isCdnEnabled) {
    let {
      callback
    } = publicPaths;
    plugins.push(callback ? new _plugins.PublicPathCallbackPlugin({
      callback
    }) : new _plugins.PublicPathChangePlugin({
      publicPaths,
      resourceHints
    }));
  }

  if (cdnMapping.isCdnEnabled) {
    plugins.push(new _plugins.CdnChangePlugin(cdnMapping));
  }

  plugins.push(new _lodashWebpackPlugin.default({
    collections: true,
    shorthands: true
  }));
  hasShadowDOM && plugins.push(new _plugins.ShadowDOMSupportPlugin());

  if (!isDevelopment) {
    enableSMap && enableSMapHook && plugins.push(new _plugins.SourceMapHookPlugin());
    optimize && plugins.push(new _plugins.OptimizeJSPlugin());
    plugins.push(new _plugins.ManifestPlugin({
      fileName: manifestFileName
    }));

    if (bundleAnalyze) {
      plugins.push(new _webpackBundleAnalyzer.BundleAnalyzerPlugin({
        analyzerMode: 'static',
        generateStatsFile: true,
        openAnalyzer: false,
        statsOptions: {
          source: false,
          normal: true,
          chunks: false,
          chunkGroups: false,
          module: false,
          assets: true,
          assetsSort: 'name'
        }
      })); // plugins.push(new ReportGeneratePlugin());
    }

    if (tpHashMapping && tpHashMapping.length > 0) {
      plugins.push(new _plugins.TPHashMappingPlugin({
        fileMappings: tpHashMapping,
        tpFolder: `${_path.default.join(process.cwd(), context, tpFolder)}/`
      }));
    }
  }

  if (!isDevelopment && serviceWorker.enableSw) {
    let {
      filePath,
      fileName = 'sw.js',
      exitPath = '/',
      replaceText = '@@'
    } = serviceWorker;

    if (!filePath) {
      throw new Error('File Path required for service worker plugin');
    }

    plugins.push(new _plugins.ServiceWorkerPlugin({
      filePath: _path.default.join(process.cwd(), filePath),
      i18nFileNameTemplate,
      fileName: fileName,
      exitPath: _path.default.join(outputFolder, exitPath),
      replaceText,
      publicPaths
    }));
  }

  customAttributes.enable && plugins.push(new _CustomAttributePlugin.CustomAttributePlugin(customAttributes));
  return plugins;
};

var _default = getProdPlugins;
exports.default = _default;