"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _webpackSources = require("webpack-sources");

var _utils = require("../utils");

var _path = _interopRequireDefault(require("path"));

var _getI18nFileUrlPathTemplate = require("./I18nSplitPlugin/utils/getI18nFileUrlPathTemplate");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import { getShortI18nAssets } from './I18nSplitPlugin/utils/hashUtils';
const cliOptions = (0, _utils.getOptions)();
const {
  app: {
    publicPaths
  },
  i18n: {
    chunkSplitEnable
  },
  efc: efcOptios
} = cliOptions;
const {
  createSDkFile
} = efcOptios;

class EFCPlugin {
  constructor(options = {}) {
    this.isDevelopment = options.isDevelopment;
    this.serverUrl = options.serverUrl;
    this.i18nFileNameTemplate = options.i18nFileNameTemplate; // this.i18nManifestFileName = options.i18nManifestFileName;

    this.options = Object.assign({}, options); // this.options.i18nManifestFileName = options.i18nManifestFileName;

    this.options.entryPointName = options.entryPointName || 'efc';
    this.options.outputFile = efcOptios.outputFile.replace('[version]', efcOptios.version);
    this.options.nameScope = options.nameScope || 'EFComponents';
    this.options.localeAttr = options.localeAttr || 'efc-locale';
  } // NOTE: this logic may be needed for contenthash cases
  // getI18nManifest(compilation) {
  //   const i18nManifestFile =
  //     compilation.assets[this.options.i18nManifestFileName];
  //   if (i18nManifestFile) {
  //     const manifest = JSON.parse(i18nManifestFile.source());
  //     return manifest;
  //   }
  //   return {};
  // }


  getI18nAssetsStr(entryPoint, compilation) {
    if (!chunkSplitEnable) {
      let i18nAsstes = {};
      let i18nFiles = Object.keys(compilation.assets).filter(assert => assert.indexOf(`i18n${_path.default.sep}`) !== -1); //hook for i18n url contains i18n/ may cause problem

      i18nAsstes = i18nFiles.reduce((res, i18nFilePath) => {
        let fileName = i18nFilePath.replace(`i18n${_path.default.sep}`, '');
        let splittedFileName = fileName.split('.');
        res[splittedFileName[0]] = i18nFilePath;
        return res;
      }, {});
      return `[${JSON.stringify(i18nAsstes)}[lang]]`;
    }

    let initalI18nAssets = entryPoint.chunks.map(chunk => (0, _getI18nFileUrlPathTemplate.getI18nFileUrlPathTemplate)(compilation, chunk, this.i18nFileNameTemplate, '@locale@'));
    return `${JSON.stringify(initalI18nAssets)}.map(urlpath => urlpath.replace(/@locale@/g, lang))`;
  }

  createFileContent(compilation) {
    const {
      entryPointName,
      localeAttr,
      nameScope,
      cdnVariableName = null
    } = this.options;
    const {
      serverUrl
    } = this; // const i18nManifest = this.getI18nManifest(compilation);

    const entryPoint = compilation.entrypoints.get(entryPointName); // const chunk = compilation.namedChunks.get(entryPointName);

    const [jsPath, cssPath,,, i18nJsPath] = !this.isDevelopment ? publicPaths : [];
    const initialFiles = entryPoint.getFiles();
    const filteredInitialFiles = initialFiles.filter(file => /\.(css|js)$/.test(file)); // const i18nAssets = getShortI18nAssets(
    //   entryPoint.chunks,
    //   i18nManifest,
    //   i18nJsPath
    // );

    const initalI18nAssets = this.getI18nAssetsStr(entryPoint, compilation, i18nJsPath);
    return `(() => {
  let langEle = document.querySelector("[${localeAttr}]");
  let lang = langEle ? langEle.getAttribute('${localeAttr}') : 'en_US';
  let prod = !${this.isDevelopment};
  let cdnVariableName = "${cdnVariableName}";
  let assetURLs = {
    //hook
    js: ${JSON.stringify(jsPath || serverUrl)},
    css: ${JSON.stringify(cssPath || serverUrl)},
    i18n: ${JSON.stringify(i18nJsPath || serverUrl)}
  };

  window.desk_urls={}
  window.desk_urls.staticDomain = 'https:' + assetURLs.js + '/';
  if (prod && cdnVariableName) {
    window["${cdnVariableName}"] = 'https:' + assetURLs.css + '/';
  }

  let initalI18nAssets = ${initalI18nAssets}.map(urlpath => "${i18nJsPath}/"+ urlpath);
  let initialAssets = initalI18nAssets.concat(${JSON.stringify(filteredInitialFiles)});

  let loadAsset = (id, type, url) => {
    return new Promise((res, rej) => {
      let el = document.createElement(type);
      // el.id = id;
      el.onload = res;
      el.error = rej;
      switch(type) {
        case 'script':
        case 'i18n':
          el.src = (type === 'i18n'? assetURLs.i18n : assetURLs.js)+'/'+url
          el.defer = 'defer';
          document.body.appendChild(el);
          break;
        case 'link':
          el.href = assetURLs.css+'/'+url
          el.rel = 'stylesheet';
          document.head.appendChild(el);
          break;
      }
    });
  };

  let memorizedPromise = null;
  ${nameScope}.onload = (cb, err) => {
    if(!memorizedPromise) {
      memorizedPromise = Promise.all(
        initialAssets.map(
          (url, index) => loadAsset(
            "${nameScope}-" + (url.endsWith("js") ? "js" : "css")  +"-"+index,
            url.endsWith("js") ? url.endsWith(".i18n.js") ? "i18n" : 'script' : 'link',
            url
          )
        )
      ).then(() => ${nameScope}.onBasicLoad(cb));
    }
    return memorizedPromise;
  };

  })();
`;
  }

  apply(compiler) {
    if (!createSDkFile) {
      return;
    }

    compiler.hooks.emit.tap('EFCPlugin', compilation => {
      const {
        entryPointName,
        outputFile
      } = this.options;
      const entryPoint = compilation.entrypoints.get(entryPointName);

      if (!entryPoint) {
        return;
      }

      const source = new _webpackSources.RawSource(this.createFileContent(compilation));
      compilation.assets[outputFile] = source; // eslint-disable-next-line no-console

      console.log('The EFC embedded code was created successfully..!!!');
    });
  }

}

exports.default = EFCPlugin;