"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _getI18nFileUrlPathTemplate = require("./I18nSplitPlugin/utils/getI18nFileUrlPathTemplate");

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  i18n: {
    chunkSplitEnable
  }
} = (0, _utils.getOptions)();

class ServiceWorkerPlugin {
  constructor(options) {
    this.i18nFileNameTemplate = options.i18nFileNameTemplate;
    this.fileName = options.fileName;
    this.serviceWorkerPath = options.filePath;
    this.writePath = options.exitPath;
    this.replaceText = options.replaceText;
    this.publicPaths = options.publicPaths;
  }

  isInitialChunk(chunk) {
    if ('canBeInitial' in chunk) {
      return chunk.canBeInitial();
    }

    return chunk.isInitial();
  }

  apply(compiler) {
    compiler.hooks.emit.tap('ServiceWorkerPlugin', compilation => {
      _fs.default.readFile(this.serviceWorkerPath, 'utf-8', (err, data) => {
        if (err) {
          throw new Error(err);
        } else {
          /* const extractedChunks = compilation.chunks.filter(chunk => {
            if ('canBeInitial' in chunk) {
              return chunk.canBeInitial();
            }
            return chunk.isInitial();
          }); */
          let [js, css,,, i18nPublicPath] = this.publicPaths; // let initialChunkUrls = [];

          let allChunkUrls = [];
          let allI18nAssets = [];
          let entrypoint = compilation.entrypoints.get('main');
          let initialChunkUrls = entrypoint.getFiles();
          /**
           * NOTE:
           *  if chunkSplitEnable is false means,
           *    serviceWorker will get i18n files path for html
           */

          let initalI18nAssets = chunkSplitEnable ? entrypoint.chunks.map(chunk => (0, _getI18nFileUrlPathTemplate.getI18nFileUrlPathTemplate)(compilation, chunk, this.i18nFileNameTemplate, '@locale@')) : [];
          compilation.chunks.filter(c => !this.isInitialChunk(c)).forEach(chunk => {
            // let isInitial = this.isInitialChunk(chunk);
            allChunkUrls = allChunkUrls.concat(chunk.files);
            chunkSplitEnable && allI18nAssets.push((0, _getI18nFileUrlPathTemplate.getI18nFileUrlPathTemplate)(compilation, chunk, this.i18nFileNameTemplate, '@locale@')); // chunk.files.forEach(fileName => {
            //   let chunkUrl = '';
            //   if (/\.css$/g.test(fileName)) {
            //     chunkUrl += `${css}${fileName}`;
            //   } else if (/\.js$/g.test(fileName)) {
            //     chunkUrl += `${js}${fileName}`;
            //   }
            //   // isInitial ? initialChunkUrls.push(chunkUrl) :
            //   allChunkUrls.push(chunkUrl);
            // });
          });
          let mod = data.replace(this.replaceText, `
function addPublicPath(url) {
  if (/\\.css$/g.test(url)) {
    return  '${css}'+url;
  } else if (/\\.js$/g.test(url)) {
    return '${js}'+url;
  }
}
self.initalI18nAssets = ${JSON.stringify(initalI18nAssets)}.map(up => "${i18nPublicPath}/" + up);
self.allI18nAssets = ${JSON.stringify(allI18nAssets)}.map(up => "${i18nPublicPath}/" + up);
self.assets = ${JSON.stringify(initialChunkUrls)}.map(addPublicPath);
self.allChunks = ${JSON.stringify(allChunkUrls)}.map(addPublicPath);`);

          if (!_fs.default.existsSync(this.writePath)) {
            _fs.default.mkdirSync(this.writePath, {
              recursive: true
            });
          }

          _fs.default.writeFileSync(_path.default.join(this.writePath, this.fileName), mod);
        }
      });
    });
  }

}

exports.default = ServiceWorkerPlugin;