"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _os = require("os");

var _getIp = _interopRequireDefault(require("../utils/getIp"));

var _getCurrentBranch = _interopRequireDefault(require("../utils/getCurrentBranch"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = {
  i18n: {
    chunkSplitEnable: {
      value: false,
      cli: 'i18n_split'
    },
    disableDefault: false,
    templateLabel: '{{--user-locale}}',
    jsResource: null,
    localeVarName: 'document.documentElement.lang',
    jsonpFunc: 'console.log',
    propertiesFolder: null
  },
  efc: {
    hasEFC: false,
    createSDkFile: false,
    nameScope: 'ZOHODESK',
    version: 'default',
    outputFile: 'zohodesk-efc-sdk-[version].js',
    localeAttr: 'data-efc-locale'
  },
  app: {
    context: {
      value: 'app',
      cli: 'app_context'
    },
    tpFolder: null,
    folder: 'src',
    vendorExclude: [],
    cssHashSelectors: {
      filenames: [],
      packages: []
    },
    customAttributes: {
      enable: false,
      attributes: null,
      jsAttributes: null,
      cssAttributes: null,
      i18nAttributes: null
    },
    server: {
      host: {
        value: (0, _os.hostname)(),
        cli: 'app_host'
      },
      port: {
        value: 9090,
        cli: 'app_port'
      },
      domain: {
        value: null,
        cli: 'app_domain'
      },
      mode: {
        value: 'dev',
        cli: 'app_mode'
      },
      branch: {
        value: 'master',
        cli: 'app_branch'
      },
      redisHost: {
        value: '127.0.0.1',
        cli: 'redis:host'
      },
      redisPort: {
        value: '6379',
        cli: 'redis:port'
      },
      disableContextURL: false,
      hasMock: false,
      mockPort: {
        value: 5000,
        cli: 'mock_port'
      }
    },
    disableES5Transpile: false,
    isReactMig: false,
    hasWidget: false,
    hasEFC: false,
    enableChunkHash: {
      value: false,
      cli: 'hash_enable'
    },
    cssUniqueness: {
      value: true,
      cli: 'css_unique'
    },
    outputFolder: {
      value: 'build',
      cli: 'output_folder'
    },
    bundleAnalyze: {
      value: false,
      cli: 'bundle_analyze'
    },
    optimize: true,
    manifestFileName: 'manifest.json',
    removeAttribute: {
      value: true,
      cli: 'rm_attr'
    },
    attrbuteNames: {
      value: ['data-testid'],
      cli: 'attr_name'
    },
    publicPaths: false,
    instrumentScript: {
      value: false,
      cli: 'instru_script'
    },
    enableSMap: {
      value: false,
      cli: 'enable_smap'
    },
    enableSMapHook: {
      value: true,
      cli: 'enable_smaphook'
    },
    hasRTL: false,
    rtlExclude: [],
    seperateCssModules: {
      value: false,
      cli: 'sep_cssmodules'
    },
    hasShadowDOM: {
      value: false,
      cli: 'has_shadowdom'
    },
    resourceHints: [],
    changeRuntimeChunkChar: false,
    classNamePrefix: {
      value: 'zd',
      cli: 'class_prefix'
    },
    selectorReplace: null,
    serviceWorker: {
      enableSw: false,
      filePath: 'sw.js',
      fileName: 'v1.js',
      exitPath: '/',
      replaceText: '//<!--AssetsFromBuild -->'
    },
    htmlTemplate: {
      inject: true
    },
    removePropTypes: false,
    customChunks: [{
      name: 'styles',
      pattern: '\\.css$'
    }],
    tpHashMapping: [],
    cdnMapping: {
      isCdnEnabled: false,
      variableName: '',
      cssTemplate: '',
      jsTemplate: '',
      i18nTemplate: ''
    }
  },
  docs: {
    server: {
      iphost: (0, _getIp.default)(),
      host: (0, _os.hostname)(),
      port: {
        value: 9292,
        cli: 'docs_port'
      },
      domain: {
        value: null,
        cli: 'docs_domain'
      },
      branch: false
    },
    componentFolder: 'src',
    cssUniqueness: {
      value: true,
      cli: 'css_unique'
    },
    folder: 'src',
    hasRTL: false,
    rtlExclude: [],
    cssHashSelectors: {
      filenames: [],
      packages: []
    },
    classNamePrefix: {
      value: 'zd',
      cli: 'class_prefix'
    }
  },
  test: {
    srcBranch: {
      value: 'master',
      cli: 'src_branch'
    },
    targetBranch: {
      value: 'master',
      cli: 'target_branch'
    },
    serviceName: {
      value: 'ZohoDeskReactApp',
      cli: 'service_name'
    },
    branchName: {
      value: null,
      cli: 'branch_name'
    },
    impactServerDomain: {
      //value: 'ht' + 'tp://desk-qa-impact.tsi.zohocorpin.com:8080',
      value: 'ht' + 'tp://desk-automation.csez.zohocorpin.com:8080',
      cli: 'impact_server_domain'
    },
    isCommitCoverage: {
      value: false,
      cli: 'commit_coverage'
    }
  },
  ssTest: {
    seleniumHub: {
      value: 'ht' + 'tp://desk-react.tsi.zohocorpin.com:4444',
      cli: 'sstest_hub'
    },
    domain: {
      value: null,
      cli: 'sstest_domain'
    },
    serviceName: {
      value: 'ZohoDeskReactApp',
      cli: 'service_name'
    },
    impactServerDomain: {
      //value: 'ht' + 'tp://desk-qa-impact.tsi.zohocorpin.com:8080',
      value: 'ht' + 'tp://desk-automation.csez.zohocorpin.com:8080',
      cli: 'impact_server_domain'
    },
    remoteBranch: false,
    referBranch: {
      value: 'master',
      cli: 'sstest_referbranch'
    },
    enableImage: {
      value: false,
      cli: 'sstest_image'
    },
    currentBranch: {
      value: (0, _getCurrentBranch.default)('git', process.cwd()),
      cli: 'sstest_currentbranch'
    },
    isStore: {
      value: false,
      cli: 'sstest_store'
    },
    isImpactRun: {
      value: false,
      cli: 'sstest_impact'
    },
    dbURL: {
      value: 'ht' + 'tp://tsi-desk-mock.tsi.zohocorpin.com:8080/Hbase',
      cli: 'sstest_db'
    },
    tableName: {
      value: 'screenshottest',
      cli: 'sstest_table'
    },
    pathToSubProjects: {
      value: 'jsapps',
      cli: 'path_to_sub_projs'
    },
    tokenGit: {
      value: 'YbByNJ3yURAm92Lhx4vW',
      cli: 'git_token'
    }
  },
  ssr: {
    server: {
      host: (0, _os.hostname)(),
      port: {
        value: 4040,
        cli: 'ssr_port'
      },
      domain: {
        value: false,
        cli: 'ssr_domain'
      },
      repoUrl: 'https://vimalesan.a@git.csez.zohocorpin.com/zohodesk/supportportal.git',
      branch: {
        value: 'theme1',
        cli: 'ssr_branch'
      },
      clientAppPath: 'jsapps/portalapp'
    },
    watch: {
      value: false,
      cli: 'ssr_watch'
    }
  },
  cluster: {
    server: {
      host: (0, _os.hostname)(),
      port: 4000,
      domain: {
        value: false,
        cli: 'cluster_domain'
      }
    }
  },
  help: {
    server: {
      host: (0, _os.hostname)(),
      port: 3000,
      domain: {
        value: false,
        cli: 'help_domain'
      }
    }
  },
  umd: {
    component: {
      watch: {
        value: false,
        cli: 'umdComp_watch'
      },
      umdVar: 'Component',
      isDocs: false,
      isHtml: false,
      outputFolder: 'build',
      cssUniqueness: {
        value: true,
        cli: 'umdComp_css_unique'
      },
      folder: 'src'
    },
    css: {
      watch: {
        value: false,
        cli: 'umdCss_watch'
      },
      outputFolder: 'dist',
      umdVar: 'CSS',
      cssUniqueness: {
        value: true,
        cli: 'umdCss_css_unique'
      },
      folder: 'src',
      publicPath: {
        value: false,
        cli: 'umdCss_public_path'
      },
      cssHashSelectors: {
        filenames: [],
        packages: []
      },
      classNamePrefix: {
        value: 'zd',
        cli: 'class_prefix'
      }
    },
    library: {
      umdVar: 'Component',
      outputFolder: 'build',
      watch: {
        value: false,
        cli: 'umdLib_watch'
      }
    }
  },
  unusedFiles: {
    usedFilesExcludes: ['node_modules'],
    appFilesExcludes: ['.docs.js$', '/__tests__/.*(spec|test).js$'],
    delete: false,
    enable: {
      value: false,
      cli: 'enable_unusedfiles'
    },
    outputFileName: 'Unusedfiles.json'
  },
  esLint: {
    enable: {
      value: false,
      cli: 'enable_eslint'
    },
    ignoreFilePaths: false,
    fix: {
      value: false,
      cli: 'eslint_fix'
    },
    isCI: {
      value: false,
      cli: 'eslint_ci'
    },
    reportType: {
      value: 'json',
      cli: 'report_type'
    },
    reportPath: {
      value: './eslint/report.json',
      cli: 'report_path'
    },
    srcBranch: {
      value: 'master',
      cli: 'src_branch'
    },
    targetBranch: {
      value: 'master',
      cli: 'target_branch'
    },
    serviceName: {
      value: 'ZohoDeskReactApp',
      cli: 'service_name'
    },
    impactServerDomain: {
      value: 'ht' + 'tp://desk-automation.csez.zohocorpin.com:8080',
      //value: 'ht' + 'tp://desk-qa-impact.tsi.zohocorpin.com:8080',
      cli: 'impact_server_domain'
    },
    impactRun: {
      value: false,
      cli: 'impact_run'
    }
  },
  clone: {
    type: {
      value: null,
      cli: 'clone_type'
    },
    url: {
      value: null,
      cli: 'clone_url'
    },
    branch: {
      value: null,
      cli: 'clone_branch'
    },
    revision: {
      value: null,
      cli: 'clone_revision'
    },
    projectName: {
      value: null,
      cli: 'clone_proj_name'
    },
    remoteName: {
      value: 'origin',
      cli: 'clone_remote_name'
    },
    cacheDir: {
      value: null,
      cli: 'clone_cacheDir'
    },
    shouldDelete: {
      value: true,
      cli: 'clone_delete'
    }
  },
  module: {
    mode: {
      value: 'prod',
      cli: 'module_mode'
    },
    disableES5Transpile: true
  }
};
exports.default = _default;