"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _https = _interopRequireDefault(require("https"));

var _webpack = _interopRequireDefault(require("webpack"));

var _express = _interopRequireDefault(require("express"));

var _child_process = require("child_process");

var _webpackDevMiddleware = _interopRequireDefault(require("webpack-dev-middleware"));

var _HMRMiddleware = _interopRequireDefault(require("../middlewares/HMRMiddleware"));

var _utils = require("../utils");

var _webpackDocs = _interopRequireDefault(require("../configs/webpack.docs.config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = isSSTest => {
  let options = (0, _utils.getOptions)();
  let {
    docs: {
      server
    }
  } = options;
  let {
    port,
    branch,
    host,
    domain,
    iphost
  } = server;
  let appPath = process.cwd();
  const app = (0, _express.default)();
  app.use(_express.default.json());
  app.use(_express.default.urlencoded({
    extended: true
  }));
  let docsConfig = (0, _webpackDocs.default)(isSSTest);
  let compiler = (0, _webpack.default)(docsConfig);
  let wdm = (0, _webpackDevMiddleware.default)(compiler, {
    logLevel: 'error',
    publicPath: docsConfig.output.publicPath,
    headers: {
      'Access-Control-Allow-Origin': '*'
    }
  });
  app.use(wdm);
  app.use((0, _HMRMiddleware.default)(compiler, {
    path: '/sockjs-node/info'
  }));
  app.use('/docs/external/', _express.default.static(_path.default.join(appPath, 'docs', 'external')));
  app.use('/docs', _express.default.static(_path.default.join(__dirname, '..', '..', 'templates', 'docs')));
  app.use('/docs/*', (req, res) => {
    res.sendFile(_path.default.join(__dirname, '..', '..', 'templates', 'docs', 'index.html'));
  });
  app.use('/author/get', (req, res) => {
    let {
      query: {
        componentName = ''
      }
    } = req;
    res.json({
      stdout: (0, _child_process.execSync)(`git blame ${componentName}`).toString()
    });
  });
  app.use('/cli/version', (req, res) => {
    res.json({
      version: require('../../package.json').version
    });
  });

  if (branch) {
    app.post('/repo/merge', (req, res) => {
      let {
        ref
      } = req.body;

      if (ref && ref.endsWith(branch)) {
        (0, _child_process.spawnSync)('git', ['pull', 'origin', branch], {
          stdio: 'inherit'
        });
      }

      res.send('done');
    });
  }

  const httpsServer = _https.default.createServer({
    key: _fs.default.readFileSync(_path.default.join(__dirname, '../../cert/key.pem')),
    cert: _fs.default.readFileSync(_path.default.join(__dirname, '../../cert/cert.pem')),
    passphrase: '9i1pqink!k11'
  }, app);

  if (!isSSTest) {
    httpsServer.listen(port, err => {
      if (err) {
        throw err;
      }

      (0, _utils.log)(`Listening at ${(0, _utils.getServerURL)(server, 'htt' + 'ps')}/docs/`);
    });
  }

  let httpPort = Number(port) + 1;
  let http = app.listen(httpPort, err => {
    if (err) {
      throw err;
    }

    if (isSSTest) {
      (0, _utils.log)(`Listening at ${(0, _utils.getServerURL)(Object.assign(server, {
        host: iphost,
        port: port
      }), 'htt' + 'p')}/docs/`);
    } else {
      (0, _utils.log)(`Listening at ${(0, _utils.getServerURL)({
        host,
        domain,
        port
      }, 'htt' + 'p')}/docs/`);
    }
  });
  return {
    compiler,
    app,
    http,
    https: httpsServer,
    wdm
  };
};

exports.default = _default;