"use strict";

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _https = _interopRequireDefault(require("https"));

var _webpack = _interopRequireDefault(require("webpack"));

var _express = _interopRequireDefault(require("express"));

var _ws = _interopRequireDefault(require("ws"));

var _compression = _interopRequireDefault(require("compression"));

var _webpackDevMiddleware = _interopRequireDefault(require("webpack-dev-middleware"));

var _httpProxyMiddleware = require("http-proxy-middleware");

var _HMRMiddleware = _interopRequireDefault(require("../middlewares/HMRMiddleware"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let options = (0, _utils.getOptions)();
let {
  app: {
    context,
    server
  }
} = options;
let {
  host,
  port,
  domain,
  mode,
  disableContextURL,
  hasMock,
  mockPort
} = server;
let isCompatableHttp2 = Number(process.version.substr(1).split('.')[0]) >= 8;
let contextURL = disableContextURL ? '' : `/${context}`;
let serverUrl = (0, _utils.getServerURL)(server, 'htt' + 'ps');
const app = (0, _express.default)();

if (hasMock) {
  app.use('/api', (0, _httpProxyMiddleware.createProxyMiddleware)({
    target: 'ht' + `tp://localhost:${mockPort}`,
    changeOrigin: true
  }));
}

app.use(_express.default.json());
app.use(_express.default.urlencoded({
  extended: true
}));
let config;

if (mode === 'prod') {
  config = require('../configs/webpack.prod.config');
  app.use((0, _compression.default)());
} else if (mode === 'dev' || mode === 'dev-no-warn') {
  config = require('../configs/webpack.dev.config');
} else {
  throw new Error('You must configure valid option in mode');
}

let compiler = (0, _webpack.default)(config);
app.use((0, _webpackDevMiddleware.default)(compiler, {
  logLevel: 'error',
  publicPath: mode === 'prod' ? contextURL === '' ? `${serverUrl}/${contextURL}` : serverUrl + contextURL : config.output.publicPath,
  headers: {
    'Access-Control-Allow-Origin': '*'
  },
  compress: mode === 'prod'
}));
app.use((0, _HMRMiddleware.default)(compiler, {
  path: '/sockjs-node/info'
}));
app.use((req, res, next) => {
  res.setHeader('Access-Control-Allow-Origin', '*');
  next();
}).use(`${contextURL}/fonts`, _express.default.static(`${context}/fonts`));
app.use('/wms/*', (req, res) => {
  res.sendFile(_path.default.join(__dirname, '..', '..', 'templates', 'wms', 'index.html'));
});

const httpsServer = _https.default.createServer({
  key: _fs.default.readFileSync(_path.default.join(__dirname, '../../cert/key.pem')),
  cert: _fs.default.readFileSync(_path.default.join(__dirname, '../../cert/cert.pem')),
  passphrase: '9i1pqink!k11'
}, app);

const wss = new _ws.default.Server({
  server: httpsServer
});
let wsPool = [];
wss.on('connection', ws => {
  wsPool.push(ws);
  ws.on('close', () => {
    wsPool = wsPool.filter(ws1 => ws1 !== ws);
  });
  ws.on('message', message => {
    (0, _utils.log)('received: %s', message);
  });
  ws.send('something');
});
app.post('/wmsmockapi', (req, res) => {
  wsPool.forEach(ws => {
    let {
      body
    } = req;

    try {
      ws.send(JSON.stringify(body));
    } catch (e) {
      (0, _utils.log)(e, body);
    }
  });
  res.send('success');
});
let webpackCompilation;
compiler.hooks.afterCompile.tap('ReactCLI', compilation => {
  webpackCompilation = compilation;
});

if (contextURL) {
  app.use(contextURL, _express.default.static(context));
  app.use(`${contextURL}/*`, (req, res) => {
    let indexHtml = webpackCompilation.assets['index.html'];
    res.send(indexHtml && indexHtml.source());
  });
} else {
  app.use(_express.default.static(context));
  app.use('/*', _express.default.static(context));
}

httpsServer.listen(port, err => {
  if (err) {
    throw err;
  }

  (0, _utils.log)(`Listening at ${serverUrl}${contextURL}/`);
});

if (isCompatableHttp2) {
  const http2 = require('http2');

  const http2Server = http2.createSecureServer({
    key: _fs.default.readFileSync(_path.default.join(__dirname, '../../cert/key.pem')),
    cert: _fs.default.readFileSync(_path.default.join(__dirname, '../../cert/cert.pem')),
    passphrase: '9i1pqink!k11'
  }); //eslint-disable-next-line

  http2Server.on('stream', (stream, headers) => {
    stream.respond({
      'content-type': 'text/html',
      ':status': 200
    });
    stream.end('<h1>Hello World! <br>Working with http2</h1>');
  });
  let http2Port = Number(port) + 1;
  http2Server.listen(http2Port, err => {
    if (err) {
      throw err;
    }

    (0, _utils.log)(`Listening at ${(0, _utils.getServerURL)({
      host,
      domain,
      port: http2Port
    }, 'htt' + 'ps')}${contextURL}/`, 'http2 server');
  });
} else {
  (0, _utils.log)("Your node version didn't adopted http2 support. Kindly update that to 8 LTS or above you can engage the http2");
}

let httpPort = Number(port) + (isCompatableHttp2 ? 2 : 1);
app.listen(httpPort, err => {
  if (err) {
    throw err;
  }

  (0, _utils.log)(`Listening at ${(0, _utils.getServerURL)({
    host,
    domain,
    port: httpPort
  }, 'ht' + 'tp')}${contextURL}/`);
});