"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUrls = exports.getFileType = exports.cssUrlReplacer = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _crypto = _interopRequireDefault(require("crypto"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let urlRegex = /url\(.*?\)/g;

let getHash = (file, isPath = false, needSubStr = true) => {
  let hash = _crypto.default.createHash('md5');

  if (isPath) {
    hash.update(_fs.default.readFileSync(file));
  } else {
    hash.update(file);
  }

  hash = hash.digest('hex');
  return hash ? needSubStr ? hash.substring(0, 20) : hash : null;
};

let getFileType = file => {
  let {
    ext
  } = _path.default.parse(file);

  if (ext === '.gif' || ext === '.png' || ext === '.jpg' || ext === '.jpeg' || ext === '.ico') {
    return 'image';
  } else if (ext === '.svg' || ext === '.woff' || ext === '.eot' || ext === '.ttf' || ext === '.woff2') {
    return 'font';
  } else if (ext === '.js') {
    return 'js';
  } else if (ext === '.css') {
    return 'css';
  }

  return null;
};

exports.getFileType = getFileType;

let formatUrl = str => {
  let char = str.includes('"') ? '"' : str.includes('\'') ? '\'' : '(';
  let statingIdx = str.indexOf(char) + 1;
  let substr = str.substring(statingIdx, str.length);
  char = char === '(' ? ')' : char;
  return substr.substring(0, substr.indexOf(char));
};

let getUrls = css => {
  let urlMatches = css.match(urlRegex);
  let src = css;

  if (urlMatches) {
    let patterns = {};
    urlMatches.forEach(pattern => {
      let url = formatUrl(pattern);
      let hash = getHash(url);
      patterns[url] = hash;
      let regex = new RegExp(pattern.replace(/([<>*()?${}|])/g, '\\$1'), 'g');
      src = src.replace(regex, hash);
    });
    return {
      urls: patterns,
      css: src
    };
  }
};

exports.getUrls = getUrls;

let cssUrlReplacer = (css, domains, chunkHash = {}) => {
  let obj = getUrls(css);
  let src = css;

  if (obj) {
    let patterns = obj.urls;
    src = obj.css;
    Object.keys(patterns).forEach(pattern => {
      let urlParts = pattern.split('/');
      let fileName = urlParts.pop();

      if (fileName.includes('#')) {
        if (fileName.includes('?')) {
          fileName = fileName.replace(/\?.*#/g, '#');
        }
      } else {
        fileName = fileName.replace(/\?.*$/g, '');
      }

      let hash = patterns[pattern];
      let filename = fileName.replace(/(\?|#).*?$/g, '');
      let regex = new RegExp(hash, 'g');
      let {
        hashedName
      } = chunkHash[filename] || fileName;

      if (domains && typeof urlParts[0] === 'string' && !urlParts[0].includes('http')) {
        let {
          font,
          image
        } = domains;
        let type = getFileType(filename);
        let customPath = type === 'image' ? `${image}/images` : type === 'font' ? `${font}/fonts` : urlParts.join('/');
        urlParts = customPath.split('/');
      }

      if (hashedName) {
        if (fileName.includes('#')) {
          if (fileName.includes('?')) {
            hashedName = `${hashedName}?${fileName.split('?')[1]}`;
          } else {
            hashedName = `${hashedName}#${fileName.split('#')[1]}`;
          }
        }
      }

      urlParts.push(hashedName || fileName);
      urlParts = urlParts.join('/');
      src = src.replace(regex, `url('${urlParts}')`);
    });
  }

  return src;
};

exports.cssUrlReplacer = cssUrlReplacer;